import { EventBusService, TransactionBaseService } from '@medusajs/medusa';
import { EntityManager } from 'typeorm';
import { SentryOptions, SentryWebHookData } from '../types';
declare type InjectedDeps = {
    manager: EntityManager;
    eventBusService: EventBusService;
};
declare type SentryFetchResult = {
    data: Record<string, string>[];
    meta: unknown;
    prev_cursor: string;
    next_cursor: string;
};
export default class SentryService extends TransactionBaseService {
    static readonly RESOLVE_KEY: string;
    protected readonly sentryApiBaseUrl = "https://sentry.io/api/0/organizations";
    protected manager_: EntityManager;
    protected transactionManager_: EntityManager | undefined;
    protected readonly config_: SentryOptions;
    protected readonly eventBusService_: EventBusService;
    constructor({ manager, eventBusService }: InjectedDeps, config: SentryOptions);
    /**
     * Fetch paginated transactions from an organisation project on sentry
     * @param organisation The organisation on which to fetch the transactions
     * @param project The project in the organisation on which to fetch the transactions
     * @param query Equation to filter the result (https://docs.sentry.io/product/sentry-basics/search/)
     * @param statsPeriod The period from when to fetch the transactions (default: 24h)
     * @param perPage The number of transaction per page
     * @param token The token to use to send request to sentry
     * @param cursor The cursor to send to fetch the transactions for a given page
     * @return The result is composed of the data and the next cursor for the pagination purpose
     */
    fetchTransactions({ organisation, project, query, statsPeriod, perPage, token, cursor, }: {
        organisation: any;
        project: any;
        query: any;
        statsPeriod: any;
        perPage: any;
        token: any;
        cursor: any;
    }): Promise<SentryFetchResult>;
    /**
     * Fetch paginated transaction events from an organisation project on sentry
     * @param transaction The transaction for which to fetch the events (e.g "GET /admin/users")
     * @param organisation The organisation on which to fetch the transactions
     * @param project The project in the organisation on which to fetch the transactions
     * @param query Equation to filter the result (https://docs.sentry.io/product/sentry-basics/search/)
     * @param statsPeriod The period from when to fetch the transactions (default: 24h)
     * @param perPage The number of transaction per page
     * @param token The token to use to send request to sentry
     * @param cursor The cursor to send to fetch the transactions for a given page
     * @return The result is composed of the data and the next cursor for the pagination purpose
     */
    fetchTransactionEvents({ transaction, organisation, project, query, statsPeriod, perPage, token, cursor, }: {
        transaction: any;
        organisation: any;
        project: any;
        query: any;
        statsPeriod: any;
        perPage: any;
        token: any;
        cursor: any;
    }): Promise<SentryFetchResult>;
    handleIssues(data: SentryWebHookData): Promise<void>;
    handleErrors(data: SentryWebHookData): Promise<void>;
    handleComments(data: SentryWebHookData): Promise<void>;
    handleAlerts(data: SentryWebHookData): Promise<void>;
    handleInstallation(data: SentryWebHookData): Promise<void>;
    protected fetchSentry({ organisation, token, queryParams, perPage }: {
        organisation: any;
        token: any;
        queryParams: any;
        perPage: any;
    }): Promise<SentryFetchResult>;
    protected static buildNextCursor(link: string): string | undefined;
    protected static buildCurrentCursor(link: string, perPage: number): string | undefined;
    protected static buildPrevCursor(nextCursor: string, perPage: number): string | undefined;
}
export {};
//# sourceMappingURL=sentry.d.ts.map